@@ -8,10 +8,10 @@ from typing import TYPE_CHECKING, Any
 import attrs
 
 from referencing._attrs import frozen
-from referencing.typing import URI
 
 if TYPE_CHECKING:
     from referencing import Resource
+    from referencing.typing import URI
 
 
 @frozen
@@ -30,13 +30,16 @@ class NoSuchResource(KeyError):
             return NotImplemented
         return attrs.astuple(self) == attrs.astuple(other)
 
+    def __hash__(self) -> int:
+        return hash(attrs.astuple(self))
+
 
 @frozen
 class NoInternalID(Exception):
     """
     A resource has no internal ID, but one is needed.
 
-    E.g. in modern JSON Schema drafts, this is the ``$id`` keyword.
+    E.g. in modern JSON Schema drafts, this is the :kw:`$id` keyword.
 
     One might be needed if a resource was to-be added to a registry but no
     other URI is available, and the resource doesn't declare its canonical URI.
@@ -49,6 +52,9 @@ class NoInternalID(Exception):
             return NotImplemented
         return attrs.astuple(self) == attrs.astuple(other)
 
+    def __hash__(self) -> int:
+        return hash(attrs.astuple(self))
+
 
 @frozen
 class Unretrievable(KeyError):
@@ -58,6 +64,14 @@ class Unretrievable(KeyError):
 
     ref: URI
 
+    def __eq__(self, other: Any) -> bool:
+        if self.__class__ is not other.__class__:
+            return NotImplemented
+        return attrs.astuple(self) == attrs.astuple(other)
+
+    def __hash__(self) -> int:
+        return hash(attrs.astuple(self))
+
 
 @frozen
 class CannotDetermineSpecification(Exception):
@@ -70,8 +84,16 @@ class CannotDetermineSpecification(Exception):
 
     contents: Any
 
+    def __eq__(self, other: Any) -> bool:
+        if self.__class__ is not other.__class__:
+            return NotImplemented
+        return attrs.astuple(self) == attrs.astuple(other)
 
-@attrs.frozen
+    def __hash__(self) -> int:
+        return hash(attrs.astuple(self))
+
+
+@attrs.frozen  # Because here we allow subclassing below.
 class Unresolvable(Exception):
     """
     A reference was unresolvable.
@@ -84,6 +106,9 @@ class Unresolvable(Exception):
             return NotImplemented
         return attrs.astuple(self) == attrs.astuple(other)
 
+    def __hash__(self) -> int:
+        return hash(attrs.astuple(self))
+
 
 @frozen
 class PointerToNowhere(Unresolvable):
@@ -93,7 +118,7 @@ class PointerToNowhere(Unresolvable):
 
     resource: Resource[Any]
 
-    def __str__(self):
+    def __str__(self) -> str:
         msg = f"{self.ref!r} does not exist within {self.resource.contents!r}"
         if self.ref == "/":
             msg += (
@@ -113,7 +138,7 @@ class NoSuchAnchor(Unresolvable):
     resource: Resource[Any]
     anchor: str
 
-    def __str__(self):
+    def __str__(self) -> str:
         return (
             f"{self.anchor!r} does not exist within {self.resource.contents!r}"
         )
@@ -130,7 +155,7 @@ class InvalidAnchor(Unresolvable):
     resource: Resource[Any]
     anchor: str
 
-    def __str__(self):
+    def __str__(self) -> str:
         return (
             f"'#{self.anchor}' is not a valid anchor, neither as a "
             "plain name anchor nor as a JSON Pointer. You may have intended "
