@@ -21,6 +21,9 @@ Schema = Union[bool, ObjectSchema]
 #: A JSON Schema Registry
 SchemaRegistry = Registry[Schema]
 
+#: The empty JSON Schema Registry
+EMPTY_REGISTRY: SchemaRegistry = Registry()
+
 
 @frozen
 class UnknownDialect(Exception):
@@ -420,7 +423,7 @@ DRAFT201909 = Specification(
             "properties",
         },
     ),
-    anchors_in=_anchor_2019,
+    anchors_in=_anchor_2019,  # type: ignore[reportGeneralTypeIssues]  TODO: check whether this is real
     maybe_in_subresource=_maybe_in_subresource_crazy_items(
         in_value={
             "additionalItems",
@@ -462,7 +465,7 @@ DRAFT7 = Specification(
         in_subarray={"allOf", "anyOf", "oneOf"},
         in_subvalues={"definitions", "patternProperties", "properties"},
     ),
-    anchors_in=_legacy_anchor_in_dollar_id,
+    anchors_in=_legacy_anchor_in_dollar_id,  # type: ignore[reportGeneralTypeIssues]  TODO: check whether this is real
     maybe_in_subresource=_maybe_in_subresource_crazy_items_dependencies(
         in_value={
             "additionalItems",
@@ -493,7 +496,7 @@ DRAFT6 = Specification(
         in_subarray={"allOf", "anyOf", "oneOf"},
         in_subvalues={"definitions", "patternProperties", "properties"},
     ),
-    anchors_in=_legacy_anchor_in_dollar_id,
+    anchors_in=_legacy_anchor_in_dollar_id,  # type: ignore[reportGeneralTypeIssues]  TODO: check whether this is real
     maybe_in_subresource=_maybe_in_subresource_crazy_items_dependencies(
         in_value={
             "additionalItems",
@@ -556,7 +559,7 @@ _SPECIFICATIONS: Registry[Specification[Schema]] = Registry(
 
 def specification_with(
     dialect_id: URI,
-    default: Specification[Any] = None,  # type: ignore[reportGeneralTypeIssues]  # noqa: E501
+    default: Specification[Any] = None,  # type: ignore[reportGeneralTypeIssues]
 ) -> Specification[Any]:
     """
     Retrieve the `Specification` with the given dialect identifier.
