@@ -24,6 +24,13 @@ ID_AND_CHILDREN = Specification(
 )
 
 
+def blow_up(uri):  # pragma: no cover
+    """
+    A retriever suitable for use in tests which expect it never to be used.
+    """
+    raise RuntimeError("This retrieve function expects to never be called!")
+
+
 class TestRegistry:
     def test_with_resource(self):
         """
@@ -104,6 +111,16 @@ class TestRegistry:
         )
         assert len(registry) == total
 
+    def test_bool_empty(self):
+        assert not Registry()
+
+    def test_bool_not_empty(self):
+        registry = Registry().with_contents(
+            [(str(i), {"foo": "bar"}) for i in range(3)],
+            default_specification=Specification.OPAQUE,
+        )
+        assert registry
+
     def test_iter(self):
         registry = Registry().with_contents(
             [(str(i), {"foo": "bar"}) for i in range(8)],
@@ -155,11 +172,21 @@ class TestRegistry:
         registry = Registry().with_resource(uri, resource)
         assert registry.contents(uri) == {"foo": "bar"}
 
+    def test_getitem_strips_empty_fragments(self):
+        uri = "http://example.com/"
+        resource = ID_AND_CHILDREN.create_resource({"ID": uri + "#"})
+        registry = resource @ Registry()
+        assert registry[uri] == registry[uri + "#"] == resource
+
     def test_contents_strips_empty_fragments(self):
         uri = "http://example.com/"
         resource = ID_AND_CHILDREN.create_resource({"ID": uri + "#"})
         registry = resource @ Registry()
-        assert registry.contents(uri) == {"ID": uri + "#"}
+        assert (
+            registry.contents(uri)
+            == registry.contents(uri + "#")
+            == {"ID": uri + "#"}
+        )
 
     def test_crawled_anchor(self):
         resource = ID_AND_CHILDREN.create_resource({"anchors": {"foo": "bar"}})
@@ -171,6 +198,12 @@ class TestRegistry:
         )
         assert retrieved.registry == registry.crawl()
 
+    def test_anchor_in_nonexistent_resource(self):
+        registry = Registry()
+        with pytest.raises(exceptions.NoSuchResource) as e:
+            registry.anchor("urn:example", "foo")
+        assert e.value == exceptions.NoSuchResource(ref="urn:example")
+
     def test_init(self):
         one = Resource.opaque(contents={})
         two = ID_AND_CHILDREN.create_resource({"foo": "bar"})
@@ -301,7 +334,7 @@ class TestRegistry:
         two = ID_AND_CHILDREN.create_resource({"foo": "bar"})
         three = ID_AND_CHILDREN.create_resource({"baz": "quux"})
 
-        def retrieve(uri):
+        def retrieve(uri):  # pragma: no cover
             pass
 
         first = Registry().with_resource("http://example.com/1", one)
@@ -334,7 +367,7 @@ class TestRegistry:
         two = ID_AND_CHILDREN.create_resource({"foo": "bar"})
         three = ID_AND_CHILDREN.create_resource({"baz": "quux"})
 
-        def retrieve(uri):
+        def retrieve(uri):  # pragma: no cover
             pass
 
         first = Registry(retrieve=retrieve).with_resource(
@@ -373,10 +406,10 @@ class TestRegistry:
         two = ID_AND_CHILDREN.create_resource({"foo": "bar"})
         three = ID_AND_CHILDREN.create_resource({"baz": "quux"})
 
-        def foo_retrieve(uri):
+        def foo_retrieve(uri):  # pragma: no cover
             pass
 
-        def bar_retrieve(uri):
+        def bar_retrieve(uri):  # pragma: no cover
             pass
 
         first = Registry(retrieve=foo_retrieve).with_resource(
@@ -389,7 +422,7 @@ class TestRegistry:
             three,
         )
 
-        with pytest.raises(Exception, match="conflict.*retriev"):  # noqa: B017
+        with pytest.raises(Exception, match="conflict.*retriev"):
             first.combine(second, third)
 
     def test_remove(self):
@@ -474,21 +507,15 @@ class TestRegistry:
             registry.get_or_retrieve("urn:uhoh")
 
     def test_retrieve_already_available_resource(self):
-        def retrieve(uri):
-            raise Exception("Oh no!")
-
         foo = Resource.opaque({"foo": "bar"})
-        registry = Registry({"urn:example": foo})
+        registry = Registry({"urn:example": foo}, retrieve=blow_up)
         assert registry["urn:example"] == foo
         assert registry.get_or_retrieve("urn:example").value == foo
 
     def test_retrieve_first_checks_crawlable_resource(self):
-        def retrieve(uri):
-            raise Exception("Oh no!")
-
         child = ID_AND_CHILDREN.create_resource({"ID": "urn:child", "foo": 12})
         root = ID_AND_CHILDREN.create_resource({"children": [child.contents]})
-        registry = Registry(retrieve=retrieve).with_resource("urn:root", root)
+        registry = Registry(retrieve=blow_up).with_resource("urn:root", root)
         assert registry.crawl()["urn:child"] == child
 
     def test_resolver(self):
@@ -749,6 +776,7 @@ class TestResolver:
         ref = "urn:example#noSuchAnchor"
         with pytest.raises(exceptions.Unresolvable) as e:
             resolver.lookup(ref)
+        assert "'noSuchAnchor' does not exist" in str(e.value)
         assert e.value == exceptions.NoSuchAnchor(
             ref="urn:example",
             resource=root,
@@ -778,6 +806,21 @@ class TestResolver:
         resolved = resolver.lookup("http://example.com/")
         assert resolved.contents == resource.contents
 
+    def test_lookup_failed_retrieved_resource(self):
+        """
+        Unretrievable exceptions are also wrapped in Unresolvable.
+        """
+
+        uri = "http://example.com/"
+
+        registry = Registry(retrieve=blow_up)
+        with pytest.raises(exceptions.Unretrievable):
+            registry.get_or_retrieve(uri)
+
+        resolver = registry.resolver()
+        with pytest.raises(exceptions.Unresolvable):
+            resolver.lookup(uri)
+
     def test_repeated_lookup_from_retrieved_resource(self):
         """
         A (custom-)retrieved resource is added to the registry returned by
@@ -786,7 +829,7 @@ class TestResolver:
         resource = Resource.opaque(contents={"foo": "baz"})
         once = [resource]
 
-        def retrieve(uri: str):
+        def retrieve(uri):
             return once.pop()
 
         resolver = Registry(retrieve=retrieve).resolver()
@@ -800,7 +843,7 @@ class TestResolver:
         resource = Resource.opaque(contents={"foo": "baz"})
         once = [resource]
 
-        def retrieve(uri: str):
+        def retrieve(uri):
             return once.pop()
 
         resolver = Registry(retrieve=retrieve).resolver()
@@ -959,10 +1002,10 @@ class TestOpaqueSpecification:
 
 @pytest.mark.parametrize(
     "cls",
-    [Registry, Resource, Specification],
+    [Anchor, Registry, Resource, Specification, exceptions.PointerToNowhere],
 )
 def test_nonsubclassable(cls):
-    with pytest.raises(Exception, match="(?i)subclassing"):  # noqa: B017
+    with pytest.raises(Exception, match="(?i)subclassing"):
 
         class Boom(cls):  # pragma: no cover
             pass
